aboutsummaryrefslogtreecommitdiff
path: root/sys/dev/tdfx
diff options
context:
space:
mode:
authorWarner Losh <imp@FreeBSD.org>2005-03-01 07:50:12 +0000
committerWarner Losh <imp@FreeBSD.org>2005-03-01 07:50:12 +0000
commit2ece8174c12474397a1963358233257347d49548 (patch)
tree60438a3fca2e5272601be58cd8fca3817dc8ed2d /sys/dev/tdfx
parent41766826eb644f2252583bbb514674a73eba5a94 (diff)
Notes
Diffstat (limited to 'sys/dev/tdfx')
-rw-r--r--sys/dev/tdfx/tdfx_pci.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/sys/dev/tdfx/tdfx_pci.c b/sys/dev/tdfx/tdfx_pci.c
index 7ad628294f46..c0d71259547e 100644
--- a/sys/dev/tdfx/tdfx_pci.c
+++ b/sys/dev/tdfx/tdfx_pci.c
@@ -120,25 +120,25 @@ tdfx_probe(device_t dev)
/*
* probe routine called on kernel boot to register supported devices. We get
* a device structure to work with, and we can test the VENDOR/DEVICE IDs to
* see if this PCI device is one that we support. Return 0 if yes, ENXIO if
* not.
*/
switch(pci_get_devid(dev)) {
case PCI_DEVICE_ALLIANCE_AT3D:
device_set_desc(dev, "ProMotion At3D 3D Accelerator");
- return 0;
+ return BUS_PROBE_DEFAULT;
case PCI_DEVICE_3DFX_VOODOO2:
device_set_desc(dev, "3DFX Voodoo II 3D Accelerator");
- return 0;
+ return BUS_PROBE_DEFAULT;
/*case PCI_DEVICE_3DFX_BANSHEE:
device_set_desc(dev, "3DFX Voodoo Banshee 2D/3D Graphics Accelerator");
- return 0;
+ return BUS_PROBE_DEFAULT;
case PCI_DEVICE_3DFX_VOODOO3:
device_set_desc(dev, "3DFX Voodoo3 2D/3D Graphics Accelerator");
- return 0;*/
+ return BUS_PROBE_DEFAULT;*/
case PCI_DEVICE_3DFX_VOODOO1:
device_set_desc(dev, "3DFX Voodoo Graphics 3D Accelerator");
- return 0;;
+ return BUS_PROBE_DEFAULT;
};
return ENXIO;
@@ -120,25 +120,25 @@ tdfx_probe(device_t dev)
* probe routine called on kernel boot to register supported devices. We get
* a device structure to work with, and we can test the VENDOR/DEVICE IDs to
- * see if this PCI device is one that we support. Return 0 if yes, ENXIO if
- * not.
+ * see if this PCI device is one that we support. Return BUS_PRROBE_DEFAULT
+ * if yes, ENXIO if not.
*/
switch(pci_get_devid(dev)) {